/*

Licensed under the GNU AFFERO GENERAL PUBLIC LICENSE Version 3 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    https://www.gnu.org/licenses/agpl-3.0.html

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package secret

import (
	"strings"

	corev1 "k8s.io/api/core/v1"
	meta "k8s.libre.sh/meta"
)

type Mutate interface {
	GetData() map[string]string
}

func MutateSecret(r Mutate, obj *corev1.Secret, m meta.Meta) error {

	data := r.GetData()

	genParams := strings.Split(obj.ObjectMeta.Annotations["settings.k8s.libre.sh/generate"], ",")

	for _, p := range genParams {
		delete(data, p)
	}

	if len(obj.Data) == 0 {
		obj.Data = make(map[string][]byte, len(data))
	}

	if len(data) > 0 {
		for k, v := range data {
			/* 			// TODO TOFIX IMPROVE SECRET GENERATION CYCLE, only generated secrets should not be updated unless asked for
			   			if len(obj.Data[k]) == 0 {
			   				obj.Data[k] = []byte(v)

						   } */
			obj.Data[k] = []byte(v)
		}
	}

	// TOD TO FIX
	meta.MutateMeta(m, obj)

	return nil
}
